@@ -8,6 +8,5 @@
 # @parameter version [String] The new version number.
 def after_gem_release_version_increment(version)
 	context["releases:update"].call(version)
-	context["utopia:project:readme:update"].call
-	context["utopia:project:agent:context:update"].call
+	context["utopia:project:update"].call
 end
